Development
===========


The code repository is hosted on `Github`_, testing, bug reports and contributions are highly welcomed and appreciated. Feel free to fork it and submit your PRs against the **develop** branch.


Development guide
~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   guidelines
   setup
   conda
   tests
   docs



.. _`Github`: https://github.com/ecmwf/earthkit
